@@ -14,6 +14,7 @@
 #    under the License.
 
 from oslo_config import cfg
+from oslo_config import types
 
 
 service_option = [cfg.BoolOpt('ceilometer',
@@ -30,11 +31,20 @@ service_option = [cfg.BoolOpt('ceilometer',
                   cfg.BoolOpt('gnocchi',
                               default=True,
                               help="Whether or not Gnocchi is expected to be"
-                                   "available")]
+                                   "available",
+                              deprecated_for_removal=True),
+                  cfg.BoolOpt('sg_core',
+                              default=False,
+                              help="Whether or not sg-core is expected to be"
+                                   "available",
+                              deprecated_for_removal=True)]
 
 telemetry_group = cfg.OptGroup(name='telemetry',
                                title='Telemetry Service Options')
 
+telemetry_services_group = cfg.OptGroup(name='telemetry_services',
+                                        title='Telemetry Services')
+
 event_group = cfg.OptGroup(name='event',
                            title='Event Service Options')
 
@@ -70,6 +80,24 @@ TelemetryGroup = [
                 default=False,
                 help="Disable SSL certificate validation when running "
                      "scenario tests"),
+    cfg.StrOpt('sg_core_service_url',
+               default="127.0.0.1:3000",
+               help="URL to sg-core prometheus endpoint"),
+    cfg.IntOpt('ceilometer_polling_interval',
+               default=300,
+               help="Polling interval configured for ceilometer. This can "
+                    "be used in test cases to wait for metrics to appear.")
+]
+
+telemetry_services_opts = [
+    cfg.ListOpt('metric_backends',
+                default=[],
+                item_type=types.String(choices=['gnocchi', 'prometheus']),
+                help="Backend store used to store metrics"),
+    cfg.StrOpt('alarm_backend',
+               default='mysql',
+               choices=['mysql', 'postgresql'],
+               help="Database used by the aodh service"),
 ]
 
 event_opts = [
